April 30, 2019.
Cambridge, MA.

# Finalized SayTeX Structure

I have now finalized the SayTeX internal structure. The idea of splitting it into two pieces is still at the core, but the ordinary user of the `saytex` package should not need to worry about that — to that extent, I have now made `saytexsyntax` a subpackage.

The terminology should now also be more clear: SayTeX is the name of the program itself, and nothing else; SayTeX Syntax is the name of the intermediary syntax used in the conversion process; and any string that does not yield an error when being the input to the SayTeX program is called recognizable (as opposed to being said to conform to SayTeX+, a term that should not be used anymore).

SayTeX is not also nicely packaged. A consequence of this is that it must use `pkg_resources` which is an external resource. The alternative, `pkgutils`, was considered, but eventually decided against since it doesn't allow for listing all files in a directory.

Packaging using this link: https://packaging.python.org/tutorials/packaging-projects/.